import { Balances, ControlClaim, EthereumAddress, HypernetLink, PublicIdentifier, PullPayment, PushPayment, Payment, PaymentId, GatewayUrl, Signature, AcceptPaymentError, RouterChannelUnknownError, BlockchainUnavailableError, VectorError, LogicalError, BalancesUnavailableError, InsufficientBalanceError, GatewayValidationError, PersistenceError, GatewayConnectorError, ProxyError, InvalidParametersError, IHypernetCore, GatewayAuthorizationDeniedError, BigNumberString } from "@hypernetlabs/objects";
import { ParentProxy } from "@hypernetlabs/utils";
import { Result, ResultAsync } from "neverthrow";
import { Subject } from "rxjs";
export default class HypernetIFrameProxy extends ParentProxy implements IHypernetCore {
    protected element: HTMLElement | null;
    protected iframeUrl: string;
    protected iframeName: string;
    protected coreInitialized: boolean;
    protected isInControl: boolean;
    protected waitInitializedPromise: Promise<void>;
    protected _handshakePromise: Promise<void> | null;
    constructor(element: HTMLElement | null, iframeUrl: string, iframeName: string);
    finalizePullPayment(_paymentId: PaymentId, _finalAmount: BigNumberString): Promise<HypernetLink>;
    initialized(): Result<boolean, never>;
    waitInitialized(): ResultAsync<void, never>;
    inControl(): Result<boolean, never>;
    getEthereumAccounts(): ResultAsync<EthereumAddress[], BlockchainUnavailableError>;
    initialize(account: EthereumAddress): ResultAsync<void, LogicalError>;
    getPublicIdentifier(): ResultAsync<PublicIdentifier, ProxyError>;
    depositFunds(assetAddress: EthereumAddress, amount: BigNumberString): ResultAsync<Balances, BalancesUnavailableError | BlockchainUnavailableError | VectorError | Error>;
    withdrawFunds(assetAddress: EthereumAddress, amount: BigNumberString, destinationAddress: EthereumAddress): ResultAsync<Balances, BalancesUnavailableError | BlockchainUnavailableError | VectorError | Error>;
    getBalances(): ResultAsync<Balances, BalancesUnavailableError>;
    getLinks(): ResultAsync<HypernetLink[], RouterChannelUnknownError | VectorError | Error>;
    getActiveLinks(): ResultAsync<HypernetLink[], RouterChannelUnknownError | VectorError | Error>;
    getLinkByCounterparty(_counterPartyAccount: PublicIdentifier): Promise<HypernetLink>;
    acceptOffers(paymentIds: PaymentId[]): ResultAsync<Result<Payment, AcceptPaymentError>[], InsufficientBalanceError | AcceptPaymentError>;
    pullFunds(paymentId: PaymentId, amount: BigNumberString): ResultAsync<Payment, RouterChannelUnknownError | VectorError | Error>;
    mintTestToken(amount: BigNumberString): ResultAsync<void, BlockchainUnavailableError>;
    authorizeGateway(gatewayUrl: GatewayUrl): ResultAsync<void, GatewayValidationError>;
    deauthorizeGateway(gatewayUrl: GatewayUrl): ResultAsync<void, PersistenceError | ProxyError | GatewayAuthorizationDeniedError>;
    getAuthorizedGateways(): ResultAsync<Map<GatewayUrl, Signature>, PersistenceError>;
    getAuthorizedGatewaysConnectorsStatus(): ResultAsync<Map<GatewayUrl, boolean>, PersistenceError>;
    displayGatewayIFrame(gatewayUrl: GatewayUrl): ResultAsync<void, GatewayConnectorError>;
    closeGatewayIFrame(gatewayUrl: GatewayUrl): ResultAsync<void, GatewayConnectorError>;
    providePrivateCredentials(privateKey: string | null, mnemonic: string | null): ResultAsync<void, InvalidParametersError>;
    private _displayCoreIFrame;
    private _closeCoreIFrame;
    /**
     * Observables for seeing what's going on
     */
    onControlClaimed: Subject<ControlClaim>;
    onControlYielded: Subject<ControlClaim>;
    onPushPaymentSent: Subject<PushPayment>;
    onPullPaymentSent: Subject<PullPayment>;
    onPushPaymentUpdated: Subject<PushPayment>;
    onPullPaymentUpdated: Subject<PullPayment>;
    onPushPaymentReceived: Subject<PushPayment>;
    onPullPaymentReceived: Subject<PullPayment>;
    onPushPaymentDelayed: Subject<PushPayment>;
    onPullPaymentDelayed: Subject<PullPayment>;
    onBalancesChanged: Subject<Balances>;
    onDeStorageAuthenticationStarted: Subject<void>;
    onDeStorageAuthenticationSucceeded: Subject<void>;
    onDeStorageAuthenticationFailed: Subject<void>;
    onGatewayAuthorized: Subject<GatewayUrl>;
    onGatewayDeauthorizationStarted: Subject<GatewayUrl>;
    onAuthorizedGatewayUpdated: Subject<GatewayUrl>;
    onAuthorizedGatewayActivationFailed: Subject<GatewayUrl>;
    onGatewayIFrameDisplayRequested: Subject<GatewayUrl>;
    onGatewayIFrameCloseRequested: Subject<GatewayUrl>;
    onInitializationRequired: Subject<void>;
    onPrivateCredentialsRequested: Subject<void>;
}
//# sourceMappingURL=HypernetIFrameProxy.d.ts.map